@@ -817,9 +817,6 @@ def show_detection(im_ms, cloud_mask, im_labels, shoreline,image_epsg, georef,
         fig = plt.figure()
         fig.set_size_inches([18, 9])
         mng = plt.get_current_fig_manager()
-        if settings['check_detection'] == True:
-            mng.window.showMaximized()
-
         # according to the image shape, decide whether it is better to have the images
         # in vertical subplots or horizontal subplots
         if im_RGB.shape[1] > 2.5*im_RGB.shape[0]:
@@ -1019,10 +1016,6 @@ def adjust_detection(im_ms, cloud_mask, im_nodata, im_labels, im_ref_buffer, ima
         fig = plt.figure()
         fig.set_size_inches([18, 9])
         mng = plt.get_current_fig_manager()
-        # if shoreline will not be shown to user do not open matplotlib window
-        if settings['check_detection'] == True:
-            mng.window.showMaximized()
-
         gs = gridspec.GridSpec(2, 3, height_ratios=[4,1])
         gs.update(bottom=0.05, top=0.95, left=0.03, right=0.97)
         ax1 = fig.add_subplot(gs[0,0])
